/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.model

import android.os.Parcelable
import kotlinx.android.parcel.Parcelize

@Parcelize
open class RequestPickerParams(
    open val pickerPickerFriendType: PickerFriendType = PickerFriendType.ALL,
    open val title: String,
    open val viewAppearance: ViewAppearance = ViewAppearance.AUTO,
    open val countryCodes: List<String>? = null,
    open val usingOsFilter: OsFilter? = OsFilter.ALL,
    open val enableLandScape: Boolean? = true,
    open val enableSearch: Boolean? = true,
    open val enableIndex: Boolean? = true,
    open val searchPlaceHolder: String? = null,
    open val showMyProfile: Boolean? = true,
    open val showFavorite: Boolean? = true,
    open val dimBlockedUser: Boolean? = true
) : Parcelable

@Parcelize
class RequestMultiPickerParams(
    override val pickerPickerFriendType: PickerFriendType = PickerFriendType.ALL,
    override val title: String,
    override val viewAppearance: ViewAppearance = ViewAppearance.AUTO,
    override val countryCodes: List<String>? = null,
    override val usingOsFilter: OsFilter? = OsFilter.ALL,
    override val enableLandScape: Boolean? = true,
    override val enableSearch: Boolean? = true,
    override val enableIndex: Boolean? = true,
    override val searchPlaceHolder: String? = null,
    override val showMyProfile: Boolean? = true,
    override val showFavorite: Boolean? = true,
    override val dimBlockedUser: Boolean? = false,
    val maxPickableCount: Int? = 30,
    val minPickableCount: Int? = 1,
    val showPickedFriend: Boolean? = true
) : RequestPickerParams(
    pickerPickerFriendType,
    title,
    viewAppearance,
    countryCodes,
    usingOsFilter,
    enableLandScape,
    enableSearch,
    enableIndex,
    searchPlaceHolder,
    showMyProfile,
    showFavorite,
    dimBlockedUser
)

enum class PickerFriendType {
    REGISTERED, INVITABLE, ALL
}

enum class ViewAppearance {
    LIGHT, DARK, AUTO
}

enum class OsFilter {
    ALL, ANDROID, IOS
}